@@ -8,6 +8,6 @@ trap 'echo "\"${last_command}\" command filed with exit code $?."' EXIT
 codespell
 ruff check --fix --exit-non-zero-on-fix .
 pylint --recursive=y examples pymodbus test
-mypy pymodbus
-pytest --cov --numprocesses auto
+mypy pymodbus examples
+pytest -x --cov --numprocesses auto
 echo "Ready to push"
