@@ -15,19 +15,19 @@ The corresponding server must be started before e.g. as:
 # --------------------------------------------------------------------------- #
 import pymodbus.client as ModbusClient
 from pymodbus import (
-    ExceptionResponse,
-    Framer,
+    FramerType,
     ModbusException,
     pymodbus_apply_logging_config,
 )
 
 
-def run_sync_simple_client(comm, host, port, framer=Framer.SOCKET):
+def run_sync_simple_client(comm, host, port, framer=FramerType.SOCKET):
     """Run sync client."""
     # activate debugging
     pymodbus_apply_logging_config("DEBUG")
 
     print("get client")
+    client: ModbusClient.ModbusBaseSyncClient
     if comm == "tcp":
         client = ModbusClient.ModbusTcpClient(
             host,
@@ -35,7 +35,6 @@ def run_sync_simple_client(comm, host, port, framer=Framer.SOCKET):
             framer=framer,
             # timeout=10,
             # retries=3,
-            # retry_on_empty=False,y
             # source_address=("localhost", 0),
         )
     elif comm == "udp":
@@ -45,7 +44,6 @@ def run_sync_simple_client(comm, host, port, framer=Framer.SOCKET):
             framer=framer,
             # timeout=10,
             # retries=3,
-            # retry_on_empty=False,
             # source_address=None,
         )
     elif comm == "serial":
@@ -54,28 +52,12 @@ def run_sync_simple_client(comm, host, port, framer=Framer.SOCKET):
             framer=framer,
             # timeout=10,
             # retries=3,
-            # retry_on_empty=False,
-            # strict=True,
             baudrate=9600,
             bytesize=8,
             parity="N",
             stopbits=1,
             # handle_local_echo=False,
         )
-    elif comm == "tls":
-        client = ModbusClient.ModbusTlsClient(
-            host,
-            port=port,
-            framer=Framer.TLS,
-            # timeout=10,
-            # retries=3,
-            # retry_on_empty=False,
-            # sslctx=None,
-            certfile="../examples/certificates/pymodbus.crt",
-            keyfile="../examples/certificates/pymodbus.key",
-            # password=None,
-            server_hostname="localhost",
-        )
     else:
         print(f"Unknown client {comm} selected")
         return
@@ -85,19 +67,30 @@ def run_sync_simple_client(comm, host, port, framer=Framer.SOCKET):
 
     print("get and verify data")
     try:
-        rr = client.read_coils(1, 1, slave=1)
+        rr = client.read_coils(1, count=1, slave=1)
     except ModbusException as exc:
         print(f"Received ModbusException({exc}) from library")
         client.close()
         return
     if rr.isError():
-        print(f"Received Modbus library error({rr})")
-        client.close()
-        return
-    if isinstance(rr, ExceptionResponse):
-        print(f"Received Modbus library exception ({rr})")
+        print(f"Received exception from device ({rr})")
         # THIS IS NOT A PYTHON EXCEPTION, but a valid modbus message
         client.close()
+        return
+    try:
+        # See all calls in client_calls.py
+        rr = client.read_holding_registers(10, count=2, slave=1)
+    except ModbusException as exc:
+        print(f"Received ModbusException({exc}) from library")
+        client.close()
+        return
+    if rr.isError():
+        print(f"Received exception from device ({rr})")
+        # THIS IS NOT A PYTHON EXCEPTION, but a valid modbus message
+        client.close()
+        return
+    value_int32 = client.convert_from_registers(rr.registers, data_type=client.DATATYPE.INT32)
+    print(f"Got int32: {value_int32}")
 
     print("close connection")
     client.close()
