@@ -4,8 +4,9 @@ from __future__ import annotations
 import dataclasses
 import random
 import struct
+from collections.abc import Callable
 from datetime import datetime
-from typing import Any, Callable
+from typing import Any
 
 from pymodbus.datastore.context import ModbusBaseSlaveContext
 
@@ -34,7 +35,7 @@ class Cell:
     access: bool = False
     value: int = 0
     action: int = 0
-    action_kwargs: dict[str, Any] | None = None
+    action_parameters: dict[str, Any] | None = None
     count_read: int = 0
     count_write: int = 0
 
@@ -46,7 +47,7 @@ class TextCell:  # pylint: disable=too-few-public-methods
     access: str
     value: str
     action: str
-    action_kwargs: str
+    action_parameters: str
     count_read: str
     count_write: str
 
@@ -68,7 +69,7 @@ class Label:  # pylint: disable=too-many-instance-attributes
     increment: str = "increment"
     invalid: str = "invalid"
     ir_size: str = "ir size"
-    kwargs: str = "kwargs"
+    parameters: str = "parameters"
     method: str = "method"
     next: str = "next"
     none: str = "none"
@@ -105,10 +106,10 @@ class Setup:
     :meta private:
     """
 
-    def __init__(self, runtime):
+    def __init__(self, runtime: Any) -> None:
         """Initialize."""
         self.runtime = runtime
-        self.config = {}
+        self.config: Any = {}
         self.config_types: dict[str, dict[str, Any]] = {
             Label.type_bits: {
                 Label.type: CellType.BITS,
@@ -147,7 +148,7 @@ class Setup:
             },
         }
 
-    def handle_type_bits(self, start, stop, value, action, action_kwargs):
+    def handle_type_bits(self, start, stop, value, action, action_parameters):
         """Handle type bits."""
         for reg in self.runtime.registers[start:stop]:
             if reg.type != CellType.INVALID:
@@ -155,9 +156,9 @@ class Setup:
             reg.value = value
             reg.type = CellType.BITS
             reg.action = action
-            reg.action_kwargs = action_kwargs
+            reg.action_parameters = action_parameters
 
-    def handle_type_uint16(self, start, stop, value, action, action_kwargs):
+    def handle_type_uint16(self, start, stop, value, action, action_parameters):
         """Handle type uint16."""
         for reg in self.runtime.registers[start:stop]:
             if reg.type != CellType.INVALID:
@@ -165,9 +166,9 @@ class Setup:
             reg.value = value
             reg.type = CellType.UINT16
             reg.action = action
-            reg.action_kwargs = action_kwargs
+            reg.action_parameters = action_parameters
 
-    def handle_type_uint32(self, start, stop, value, action, action_kwargs):
+    def handle_type_uint32(self, start, stop, value, action, action_parameters):
         """Handle type uint32."""
         regs_value = ModbusSimulatorContext.build_registers_from_value(value, True)
         for i in range(start, stop, 2):
@@ -177,11 +178,11 @@ class Setup:
             regs[0].value = regs_value[0]
             regs[0].type = CellType.UINT32
             regs[0].action = action
-            regs[0].action_kwargs = action_kwargs
+            regs[0].action_parameters = action_parameters
             regs[1].value = regs_value[1]
             regs[1].type = CellType.NEXT
 
-    def handle_type_float32(self, start, stop, value, action, action_kwargs):
+    def handle_type_float32(self, start, stop, value, action, action_parameters):
         """Handle type uint32."""
         regs_value = ModbusSimulatorContext.build_registers_from_value(value, False)
         for i in range(start, stop, 2):
@@ -191,11 +192,11 @@ class Setup:
             regs[0].value = regs_value[0]
             regs[0].type = CellType.FLOAT32
             regs[0].action = action
-            regs[0].action_kwargs = action_kwargs
+            regs[0].action_parameters = action_parameters
             regs[1].value = regs_value[1]
             regs[1].type = CellType.NEXT
 
-    def handle_type_string(self, start, stop, value, action, action_kwargs):
+    def handle_type_string(self, start, stop, value, action, action_parameters):
         """Handle type string."""
         regs = stop - start
         reg_len = regs * 2
@@ -213,7 +214,7 @@ class Setup:
             reg.type = CellType.NEXT
         self.runtime.registers[start].type = CellType.STRING
         self.runtime.registers[start].action = action
-        self.runtime.registers[start].action_kwargs = action_kwargs
+        self.runtime.registers[start].action_parameters = action_parameters
 
     def handle_setup_section(self):
         """Load setup section."""
@@ -304,7 +305,7 @@ class Setup:
                     self.runtime.action_name_to_id[
                         entry.get(Label.action, type_entry[Label.action])
                     ],
-                    entry.get(Label.kwargs, None),
+                    entry.get(Label.parameters, None),
                 )
             del self.config[section]
 
@@ -439,7 +440,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
                 {"addr": [32, 34], "value": 0xF1},  --> with value
                 {"addr": [35, 36], "action": "increment"},  --> with action
                 {"addr": [37, 38], "action": "increment", "value": 0xF1}  --> with action and value
-                {"addr": [37, 38], "action": "increment", "kwargs": {"min": 0, "max": 100}}  --> with action with arguments
+                {"addr": [37, 38], "action": "increment", "parameters": {"min": 0, "max": 100}}  --> with action with arguments
             ],
             "uint16": [  --> Define uint16 (1 register == 2 bytes)
                 --> same as type_bits
@@ -494,8 +495,8 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         text_cell.count_read = str(reg.count_read)
         text_cell.count_write = str(reg.count_write)
         text_cell.action = self.action_id_to_name[reg.action]
-        if reg.action_kwargs:
-            text_cell.action = f"{text_cell.action}({reg.action_kwargs})"
+        if reg.action_parameters:
+            text_cell.action = f"{text_cell.action}({reg.action_parameters})"
         if reg.type in (CellType.INVALID, CellType.UINT16, CellType.NEXT):
             text_cell.value = str(reg.value)
             build_len = 0
@@ -541,7 +542,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         i = address
         while i < end_address:
             reg = self.registers[i]
-            if fx_write and not reg.access or reg.type == CellType.INVALID:
+            if (fx_write and not reg.access) or reg.type == CellType.INVALID:
                 return False
             if not self.type_exception:
                 i += 1
@@ -588,9 +589,9 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             real_address = self.fc_offset[func_code] + address
             for i in range(real_address, real_address + count):
                 reg = self.registers[i]
-                kwargs = reg.action_kwargs if reg.action_kwargs else {}
+                parameters = reg.action_parameters if reg.action_parameters else {}
                 if reg.action:
-                    self.action_methods[reg.action](self.registers, i, reg, **kwargs)
+                    self.action_methods[reg.action](self.registers, i, reg, **parameters)
                 self.registers[i].count_read += 1
                 result.append(reg.value)
         else:
@@ -601,9 +602,9 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             for i in range(real_address, real_address + reg_count):
                 reg = self.registers[i]
                 if reg.action:
-                    kwargs = reg.action_kwargs or {}
+                    parameters = reg.action_parameters or {}
                     self.action_methods[reg.action](
-                        self.registers, i, reg, **kwargs
+                        self.registers, i, reg, **parameters
                     )
                 self.registers[i].count_read += 1
                 while count and bit_index < 16:
@@ -706,7 +707,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
             reg2.value = new_regs[1]
 
     @classmethod
-    def action_timestamp(cls, registers, inx, _cell, **_kwargs):
+    def action_timestamp(cls, registers, inx, _cell, **_parameters):
         """Set current time.
 
         :meta private:
@@ -721,7 +722,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         registers[inx + 6].value = system_time.second
 
     @classmethod
-    def action_reset(cls, _registers, _inx, _cell, **_kwargs):
+    def action_reset(cls, _registers, _inx, _cell, **_parameters):
         """Reboot server.
 
         :meta private:
@@ -729,7 +730,7 @@ class ModbusSimulatorContext(ModbusBaseSlaveContext):
         raise RuntimeError("RESET server")
 
     @classmethod
-    def action_uptime(cls, registers, inx, cell, **_kwargs):
+    def action_uptime(cls, registers, inx, cell, **_parameters):
         """Return uptime in seconds.
 
         :meta private:
