@@ -1,13 +1,11 @@
 """Transport."""
 __all__ = [
+    "NULLMODEM_HOST",
     "CommParams",
     "CommType",
     "ModbusProtocol",
-    "ModbusProtocolStub",
-    "NULLMODEM_HOST",
 ]
 
-from pymodbus.transport.stub import ModbusProtocolStub
 from pymodbus.transport.transport import (
     NULLMODEM_HOST,
     CommParams,
